@@ -1,16 +1,14 @@
 package LWP::Authen::Digest;
+
 use strict;
+use base 'LWP::Authen::Basic';
 
 require Digest::MD5;
 
-sub authenticate
-{
-    my($class, $ua, $proxy, $auth_param, $response,
-       $request, $arg, $size) = @_;
+sub auth_header {
+    my($class, $user, $pass, $request, $ua, $h) = @_;
 
-    my($user, $pass) = $ua->get_basic_credentials($auth_param->{realm},
-                                                  $request->url, $proxy);
-    return $response unless defined $user and defined $pass;
+    my $auth_param = $h->{auth_param};
 
     my $nc = sprintf "%08X", ++$ua->{authen_md5_nonce_count}{$auth_param->{nonce}};
     my $cnonce = sprintf "%8x", time;
@@ -28,7 +26,7 @@ sub authenticate
     push(@digest, $auth_param->{nonce});
 
     if ($auth_param->{qop}) {
-	push(@digest, $nc, $cnonce, $auth_param->{qop});
+	push(@digest, $nc, $cnonce, ($auth_param->{qop} =~ m|^auth[,;]auth-int$|) ? 'auth' : $auth_param->{qop});
     }
 
     $md5->add(join(":", $request->method, $uri));
@@ -42,7 +40,7 @@ sub authenticate
     my %resp = map { $_ => $auth_param->{$_} } qw(realm nonce opaque);
     @resp{qw(username uri response algorithm)} = ($user, $uri, $digest, "MD5");
 
-    if (($auth_param->{qop} || "") eq "auth") {
+    if (($auth_param->{qop} || "") =~ m|^auth([,;]auth-int)?$|) {
 	@resp{qw(qop cnonce nc)} = ("auth", $cnonce, $nc);
     }
 
@@ -63,25 +61,8 @@ sub authenticate
 	push(@pairs, "$_=" . qq("$resp{$_}"));
     }
 
-    my $auth_header = $proxy ? "Proxy-Authorization" : "Authorization";
     my $auth_value  = "Digest " . join(", ", @pairs);
-
-    # Need to check this isn't a repeated fail!
-    my $r = $response;
-    while ($r) {
-	my $auth = $r->request->header($auth_header);
-	if ($auth && $auth eq $auth_value) {
-	    # here we know this failed before
-	    $response->header("Client-Warning" =>
-			      "Credentials for '$user' failed before");
-	    return $response;
-	}
-	$r = $r->previous;
-    }
-
-    my $referral = $request->clone;
-    $referral->header($auth_header => $auth_value);
-    return $ua->request($referral, $arg, $size, $response);
+    return $auth_value;
 }
 
 1;
